/// <reference types="react" />
import { ReactElement } from "react";
import { TransitionPlainStyle, Style, PlainStyle } from "react-motion";
import AnimationPhases from "./AnimationPhases";
import PlayStrategies from "./PlayStrategies";
export declare type StyleCalculator = (style: PlainStyle, phase: AnimationPhases) => Style;
export declare type StyleCalculators = {
    container: StyleCalculator;
    oldPlay: StyleCalculator;
    newPlay: StyleCalculator;
};
export declare type StyleKeys = "container" | "oldPlay" | "newPlay";
export interface InitMotionStyle extends TransitionPlainStyle {
    key: StyleKeys;
}
export declare type NumberToStyle = (style: PlainStyle, phase: AnimationPhases) => {
    [key: string]: string;
};
export declare type NumberToStyles = {
    container: NumberToStyle;
    oldPlay: NumberToStyle;
    newPlay: NumberToStyle;
};
export declare type NextPhaseChecker = (style: PlainStyle) => boolean | null | undefined;
export declare type NextPhaseCheckers = {
    container: NextPhaseChecker;
    oldPlay: NextPhaseChecker;
    newPlay: NextPhaseChecker;
};
export declare type ExtendedStyleKeys = StyleKeys | "nextPhase";
export interface ExtendedMotionStyle extends TransitionPlainStyle {
    key: StyleKeys | "nextPhase";
}
export interface ExtendedPlainMotionStyle extends TransitionPlainStyle {
    key: StyleKeys | "nextPhase";
}
export declare type CombinedStyleCalculator = (prevStyles: ExtendedPlainMotionStyle[]) => ExtendedMotionStyle[];
export declare type ArenaSwitchAnimationProps = {
    children: ReactElement<{}>;
    initStyles: InitMotionStyle[];
    styleCalculators: StyleCalculators;
    nextPhaseCheckers: NextPhaseCheckers;
    numberToStyles: NumberToStyles;
};
export declare type ArenaSwitchAnimationConnectedProps = {
    actions: {
        setState: (state: State) => void;
        nextPhase: (phase: AnimationPhases, oldPlayKey: string, oldPlay: PlayEntity) => void;
        playNext: (PlayStrategies?: PlayStrategies) => void;
    };
} & ArenaSwitchAnimationProps & State;
export declare type PlayEntity = {
    element?: ReactElement<{}> | null | undefined;
};
export declare type State = {
    play1: PlayEntity;
    play2: PlayEntity;
    newPlayKey: "play1" | "play2";
    playlist: Array<PlayEntity>;
    autoClearPlay: PlayEntity | null;
    phase: AnimationPhases;
};
