var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_motion_1 = require("react-motion");
var AnimationPhases_1 = require("./AnimationPhases");
var utils_1 = require("./utils");
var ArenaSwitchAnimation = /** @class */ (function (_super) {
    __extends(ArenaSwitchAnimation, _super);
    function ArenaSwitchAnimation() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ArenaSwitchAnimation.prototype.componentWillMount = function () {
        var _this = this;
        this.props.actions.playNext();
        var state = {
            initStyles: this.props.initStyles.concat({
                key: "nextPhase",
                style: { phase: AnimationPhases_1.default.IN }
            })
        };
        Object.assign(state, utils_1.calcKeys(this.props.newPlayKey));
        state.styleCalculator = utils_1.buildStyleCalculator(this.props.styleCalculators, this.props.phase, this.props.nextPhaseCheckers, function (phase) {
            return setImmediate(function () {
                return _this.props.actions.nextPhase(phase, state.oldPlayKey, _this.props[state.oldPlayKey]);
            });
        });
        this.setState(state);
    };
    ArenaSwitchAnimation.prototype.componentWillReceiveProps = function (nextProps) {
        var state = Object.assign({}, this.state);
        if (nextProps.newPlayKey !== this.props.newPlayKey) {
            Object.assign(state, utils_1.calcKeys(nextProps.newPlayKey));
        }
        if (nextProps.actions !== this.props.actions ||
            nextProps.phase !== this.props.phase ||
            nextProps.newPlayKey !== this.props.newPlayKey ||
            nextProps.styleCalculators !== this.props.styleCalculators ||
            nextProps.nextPhaseCheckers !== this.props.nextPhaseCheckers) {
            state.styleCalculator = utils_1.buildStyleCalculator(nextProps.styleCalculators, nextProps.phase, nextProps.nextPhaseCheckers, function (phase) {
                return setImmediate(function () {
                    return nextProps.actions.nextPhase(phase, state.oldPlayKey, nextProps[state.oldPlayKey]);
                });
            });
        }
        if (nextProps.initStyles !== this.props.initStyles) {
            var nextPhaseStyle = this.state.initStyles.find(function (style) { return style.key === "nextPhase"; });
            state.initStyles = nextProps.initStyles.concat(nextPhaseStyle);
        }
        this.setState(state);
        if (nextProps.phase === AnimationPhases_1.default.IN &&
            nextProps.playlist.length > 0) {
            nextProps.actions.playNext();
        }
        else if (nextProps.phase === AnimationPhases_1.default.OUT &&
            nextProps.autoClearPlay) {
            nextProps.actions.playNext();
        }
    };
    ArenaSwitchAnimation.prototype.render = function () {
        var _this = this;
        var _a = this.props, phase = _a.phase, numberToStyles = _a.numberToStyles;
        var _b = this.state, newPlayKey = _b.newPlayKey, oldPlayKey = _b.oldPlayKey, initStyles = _b.initStyles, styleCalculator = _b.styleCalculator;
        return (React.createElement(react_motion_1.TransitionMotion, { defaultStyles: initStyles, styles: styleCalculator }, function (interpolatedStyles) {
            var containerStyle, newPlayStyle, oldPlayStyle;
            var animationPhase = interpolatedStyles.find(function (styleObj) { return styleObj.key === "nextPhase"; }).style.phase;
            interpolatedStyles.forEach(function (styleObj) {
                var key = styleObj.key, style = styleObj.style;
                switch (key) {
                    case "container":
                        containerStyle = numberToStyles.container(style, phase);
                        break;
                    case "oldPlay":
                        oldPlayStyle = numberToStyles.oldPlay(style, phase);
                        break;
                    case "newPlay":
                        newPlayStyle = numberToStyles.newPlay(style, phase);
                        break;
                }
            });
            return (React.createElement("div", { style: containerStyle },
                _this.props.children,
                React.createElement("div", { key: oldPlayKey, style: oldPlayStyle }, _this.props[oldPlayKey].element),
                animationPhase === AnimationPhases_1.default.IN ? null : (React.createElement("div", { key: newPlayKey, style: newPlayStyle }, _this.props[newPlayKey].element))));
        }));
    };
    return ArenaSwitchAnimation;
}(React.Component));
exports.default = ArenaSwitchAnimation;
